@@ -5,7 +5,7 @@
 *	Created:  Sun Jan 24 20:36:39 PST 1999				      *
 *	Contents: DGPS over ip -- get RTCM signals from a remote tcp source   *
 *									      *
-*	$Id: dgpsip.c,v 1.43 1999/08/25 19:20:19 wolfgang Exp $
+*	$Id: dgpsip.c,v 1.44 1999/10/14 23:30:26 wolfgang Exp $
 ******************************************************************************/
 
 /*
@@ -79,6 +79,10 @@
 #define BUFSZ     (4 * 1024)
 #define NMEABUFSZ (4 * 1024)
 
+#ifndef AF_INET6
+# define AF_INET6 0x6666     /* IP version 6 */
+#endif
+
 int             verbose = 0;
 
 void            usage(void);
@@ -146,7 +150,7 @@ main(int argc,
                     ttybaud = 4800;
     FILE           *posf = NULL;
 
-    while ((c = getopt(argc, argv, "c:dh:n:N:o:p:rs:v:wP:BS:64")) != EOF) {
+    while ((c = getopt(argc, argv, "c:dh:n:N:o:p:rs:v:wP:BS:64:t")) != EOF) {
 	switch (c) {
 	case 'c':		/* capture GPS output to file */
 	    if ((posf = fopen(optarg, "w")) == NULL) {
